import { ThemedText } from "@/components/ThemedText";
import { useEffect } from "react";
import { StyleSheet } from "react-native";
import {
  Camera,
  useCameraDevice,
  useCameraPermission,
  useFrameProcessor,
  useSkiaFrameProcessor,
} from "react-native-vision-camera";

export default function ScannerScreen() {
  const device = useCameraDevice("back");
  const { hasPermission, requestPermission } = useCameraPermission();

  // const devices = Camera.getAvailableCameraDevices();
  // console.log(JSON.stringify(devices, null, 2));

  const skiaFrameProcessor = useSkiaFrameProcessor((frame) => {
    "worklet";
    frame.render();
  }, []);

  const frameProcessor = useFrameProcessor((frame) => {
    "worklet";
  }, []);

  useEffect(() => {
    if (!hasPermission) {
      requestPermission();
    }
  }, []);

  if (!hasPermission)
    return <ThemedText type="title">No Permission</ThemedText>;
  if (device == null) return <ThemedText type="title">No Device</ThemedText>;

  return (
    <Camera
      style={StyleSheet.absoluteFill}
      device={device}
      isActive={true}
      pixelFormat="rgb"
      frameProcessor={skiaFrameProcessor}
    />
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    justifyContent: "center",
    alignItems: "center",
  },
});
